==> opennms_21.0.3-1.tar.gz: opennms-source/core/test-api/lib/src/main/java/org/opennms/core/test/LoggingEvent.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2012-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.core.test;

public class LoggingEvent {
    private String m_name;
    private Level m_level;
    private String m_message;

    public LoggingEvent(final String name, final Level level, final String message) {
        m_name = name;
        m_level = level;
        m_message = message;
    }

    public String getLoggerName() {
        return m_name;
    }

    public String getMessage() {
        return m_message;
    }

    public Level getLevel() {
        return m_level;
    }

    @Override
    public String toString() {
        return m_name + "(" + m_level + "): " + m_message;
    }
}

==> opennms_22.0.3-1.tar.gz: opennms-source/core/test-api/lib/src/main/java/org/opennms/core/test/LoggingEvent.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2012-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.core.test;

public class LoggingEvent {
    private final String m_name;
    private final Level m_level;
    private final String m_message;

    public LoggingEvent(final String name, final Level level, final String message) {
        m_name = name;
        m_level = level;
        m_message = message;
    }

    public String getLoggerName() {
        return m_name;
    }

    public String getMessage() {
        return m_message;
    }

    public Level getLevel() {
        return m_level;
    }

    @Override
    public String toString() {
        return m_name + "(" + m_level + "): " + m_message;
    }
}
